import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)

/**
 * Turtle using recursion to draw a fractal tree
 * 
 * @author Paul Clark, Ralf Gesellensetter
 * @version 0.2
 */
public class TreeTurtle extends Turtle
{
    private double size;              // in pixels
    private double scale;             // must be < 1 to shrink size in order to terminate
    
    public TreeTurtle()
    {
        // Default parameters, bit like an Ash tree
        size = 100;
        scale= 0.66;
        turnNorth();
    }
    
    public TreeTurtle(int pixels, double s)
    {
        // Default parameters, bit like an Ash tree
        size = (double) pixels;
        scale= s;
    }


    public void setSize(double pixels)
    {
        size = pixels;
    }

    public void setScale(double s)
    {
        scale = s;
    }

    /**
     * Action:  Draw one tree and return to start position
     */
    public void act()
    {
        // Draw tree
        penDown();
        tree(size);
        penUp();
    }

    /**
     * Recursive draw method - recurses to 'depth' further levels
     */
    public void tree(double size) // starting point == point of return
    {
        move(size);
        
        if (size >= 1)     // no trees smaller than one pixel; 
        {
            // Just a plain twig
            turn(-60); tree(size*scale);
            turn(120); tree(size*scale);
            turn(-60);
        }
           
        move(-size); // return turtle to starting point
    }
}
